import * as React from 'react';
import { Helmet } from 'react-helmet';
import { ViewHeadRendererContext } from 'react-navi';
export function HelmetProvider(_a) {
    var canUseDOM = _a.canUseDOM, context = _a.context, children = _a.children;
    // react-helmet thinks it's in a browser because of JSDOM, so we need to
    // manually let it know that we're doing static rendering.
    if (canUseDOM !== undefined) {
        Helmet.canUseDOM = canUseDOM;
    }
    if (context && !Helmet.canUseDOM) {
        context.getHelmet = function () {
            return Helmet.renderStatic();
        };
    }
    return (React.createElement(ViewHeadRendererContext.Provider, { value: renderViewHead }, children));
}
// Memoize these to stop a bizarre react-helmet infinite loop bug when titles
// are recreated on each render
var titles = {};
function createTitleElement(str) {
    var title = titles[str];
    if (!title) {
        title = titles[str] = React.createElement("title", null, str);
    }
    return title;
}
export function renderViewHead(chunks) {
    var headAndTitleChunks = chunks.filter(function (chunk) { return chunk.type === 'title' || chunk.type === 'head'; });
    var helmet = headAndTitleChunks &&
        headAndTitleChunks.length && React.createElement.apply(React, [Helmet,
        null].concat(headAndTitleChunks.map(function (chunk) {
        return chunk.type === 'title'
            ? createTitleElement(chunk.title)
            : chunk.head.type === React.Fragment || chunk.head.type === 'head'
                ? chunk.head.props.children
                : chunk.head;
    })));
    return helmet || null;
}
// If building with navi-scripts, we'll need to register this module so that
// it can use it to add <head> tags to the build output.
if (typeof window !== 'undefined') {
    var app = window['NaviScripts'];
    if (!app) {
        app = window['NaviScripts'] = {};
    }
    if (!app.head) {
        app.head = HelmetProvider;
    }
}
export default HelmetProvider;
//# sourceMappingURL=index.js.map